<?php
/*
* $Id: cm_pi_options_images.php
* $Loc: /includes/modules/content/product_info/
*
* Name: OptionsImages
* Version: 2.6
* Release Date: 2024-07-19
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class cm_pi_options_images extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_CONTENT_PI_OI_';

    public function __construct() {
      parent::__construct(__FILE__);

      if (!file_exists(DIR_FS_CATALOG . 'templates/' . TEMPLATE_SELECTION . '/includes/hooks/shop/siteWide/bsSelect.php')) {
        $this->enabled = false;
        $this->description = '<div class="alert alert-danger" role="alert">' .
                                 MODULE_CONTENT_PI_OI_SHOP_BS_SELECT_HOOK_WARNING .
                             '</div>' .
                             $this->description;
      }
      if (!file_exists(DIR_FS_CATALOG . 'includes/hooks/admin/products_attributes/OptImages.php')) {
        $this->enabled = false;
        $this->description = '<div class="alert alert-danger" role="alert">' .
                                 MODULE_CONTENT_PI_OI_ADMIN_OPTIMAGES_HOOK_WARNING .
                             '</div>' .
                             $this->description;
      }
    }

    public function execute() {
      $options = $this->build_options();
      if (count($options)) {
        $tpl_data = [ 'group' => $this->group, 'file' => __FILE__ ];
        include 'includes/modules/content/cm_template.php';
      }
    }

    public function build_options() {
      global $currencies, $product;

      $content_width = (int)MODULE_CONTENT_PI_OI_CONTENT_WIDTH;

      $attributes = $product->get('attributes');

      $options = [];
      foreach ($attributes as $option_id => $attribute) {
        $option_choices = [];

        if (MODULE_CONTENT_PI_OI_HELPER == 'True') {
          $option_choices[] = ['id' => '', 'text' => MODULE_CONTENT_PI_OI_ENFORCE_SELECTION];
        }

        foreach ($attribute['values'] as $value_id => $value) {
          $text = $value['name'];
          if ($value['price'] != '0') {
            $text .= ' (' . $value['prefix']
                   . $currencies->display_price($value['price'], Tax::get_rate($product->get('tax_class_id')))
                   . ') ';
          }
          $option_choices[] = ['id' => $value_id, 'text' => $text, 'image' => ($value['image'])?? ''];
        }

        $options[] = [
          'id' => $option_id,
          'name' => $attribute['name'],
          'choices' => $option_choices,
          'selection' => is_string($_GET['products_id'])
                       ? $_SESSION['cart']->contents[$_GET['products_id']]['attributes'][$option_id] ?? ''
                       : '',
        ];
      }

      return $options;
    }

    protected function get_parameters() {
      return [
        $this->config_key_base . 'VERSION' => [
          'title' => 'Current Version',
          'value' => '2.6.',
          'desc' => 'Version info. It is read only',
          'set_func' => 'cm_pi_options_images::readonly(',
        ],
        $this->config_key_base . 'STATUS' => [
          'title' => 'Enable Options Images Module',
          'value' => 'True',
          'desc' => 'Should this module be shown on the product info page?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'CONTENT_WIDTH' => [
          'title' => 'Content Container',
          'value' => 'col-sm-12',
          'desc' => 'What container should the content be shown in? (col-*-12 = full width, col-*-6 = half width).',
        ],
        $this->config_key_base . 'HELPER' => [
          'title' => 'Add Helper Text',
          'value' => 'True',
          'desc' => 'Should first option in dropdown be Helper Text?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'ENFORCE' => [
          'title' => 'Enforce Selection',
          'value' => 'True',
          'desc' => 'Should customer be forced to select option(s)?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        $this->config_key_base . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '80',
          'desc' => 'Sort order of display. Lowest is displayed first.',
        ],
        $this->config_key_base . 'REMOVE_DATA' => [
          'title' => 'Uninstall Removes Database entries',
          'value' => 'False',
          'desc' => 'Do you want to remove the options images database column in the products_attributes table when uninstall the module? All your existing options images entries will be lost, use this option only it you are sure that you will not use options images any more.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
      ];
    }

    function install($parameter_key = null) {
      parent::install($parameter_key);
      global $db;

      // ADDED FIELDS
      if (mysqli_num_rows($db->query("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='". DB_DATABASE . "' AND TABLE_NAME='products_attributes' AND COLUMN_NAME LIKE 'option_image'")) != 1 ) {
        $db->query("AlTER TABLE products_attributes ADD option_image varchar(127) NULL default NULL");
      }
      // ADD FIELD for options values images
      if (mysqli_num_rows($db->query("SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_SCHEMA='". DB_DATABASE . "' AND TABLE_NAME='products_options_values' AND COLUMN_NAME LIKE 'products_options_values_image'")) != 1 ) {
        $db->query("AlTER TABLE products_options_values ADD products_options_values_image varchar(127) NULL default NULL");
      }

      // Create image directory for options images
      if(!is_dir(DIR_FS_CATALOG . 'images/options/'))mkdir(DIR_FS_CATALOG . 'images/options/', 0755);
    }

    function remove($parameter_key = null) {
      parent::remove($parameter_key);
      global $db;

      // DELETE ADDED FIELDS
      if ( defined('MODULE_CONTENT_PI_OI_REMOVE_DATA') && MODULE_CONTENT_PI_OI_REMOVE_DATA == 'True' ) {
        $db->query("ALTER TABLE products_options_values DROP COLUMN products_options_values_image");
        $db->query("ALTER TABLE products_attributes DROP COLUMN option_image");
      }
    }

    public static function readonly($value) {
      return $value;
    }

////
// Output a form pull down menu for Option Images Phoenix
    function options_images_pull_down_menu($name, $values, $default = '', $parameters = '', $required = false) {
      $field = '<select name="' . htmlspecialchars($name) . '"';

      if (!empty($parameters)) $field .= ' ' . $parameters;

      $field .= ' class="form-control selectpicker"' .  ((MODULE_CONTENT_PI_OI_ENFORCE == 'True')? ' data-width="85%"' : '') . '>';

      if (empty($default)) {
        if (is_string($_GET[$name] ?? null)) {
          $default = stripslashes($_GET[$name]);
        } elseif (is_string($_POST[$name] ?? null)) {
          $default = stripslashes($_POST[$name]);
        }
      }

      foreach ($values as $value) {
        $field .= '<option value="' . htmlspecialchars($value['id']) . '"';
        if ($default == $value['id']) {
          $field .= ' selected="selected"';
        }

       $option_name = htmlspecialchars(str_replace(['"', '\'', '<', '>'], ['&quot;', '&#039;', '&lt;', '&gt;'], $value['text']));

       if( !empty( $value['image'] ) ) {
         $field .= ' data-content=\'' . new Image('images/options/' . $value['image'], ['title' => $option_name, 'width' => '30', 'height' => '30']) . '&nbsp;' . $option_name . '\'';
       }

       $field .= '>' . $option_name . '</option>';

      }
      $field .= '</select>';

      if ($required == true) $field .= TEXT_FIELD_REQUIRED;

      return $field;
    }

  }
